﻿using System;
using System.Configuration;
using System.Data;
using System.Data.OleDb;
using System.IO;
using System.Text;

using System.Web;
using System.Web.Services;
using System.Web.Services.Protocols;
using Microsoft.Web.Services3;
using Passkorea.File;

[WebService(Namespace = "http://passkorea.net/")]
[WebServiceBinding(ConformsTo = WsiProfiles.BasicProfile1_1)]
public class UploadService : WebService
{
    private string __strErr = "";
    private string strCon = ConfigurationSettings.AppSettings["strConnection"].ToString();
    private FileUpload fu;
    private FileDownload fd;

    public UploadService () {
        //디자인된 구성 요소를 사용하는 경우 다음 줄의 주석 처리를 제거합니다. 
        //InitializeComponent();
        fu = new FileUpload();
        fd = new FileDownload();
    }

    /// <summary>
    /// 업로드 경로를 가져온다.
    /// </summary>
    /// <param name="strArgs">경로를 가져오기 위한 값 (아이디|그룹명|폴더명|파일명)</param>
    /// <param name="lUploadSize"></param>
    /// <returns></returns>
    [WebMethod(EnableSession = true)]
    public string GetUploadPath(string strArgs, long lUploadSize)
    {
        string strPath = "";
        string[] strValue;
        string strFilename = "";

        try
        {
            if (strArgs.Trim() == "")
                SoapCustomException("", "No Data");

            strValue = Encoding.UTF8.GetString(Convert.FromBase64String(strArgs)).Split(':');

            if (strValue.Length == 3)
            {
                // 웹메일 일때 사용자 경로를 가져온다.
                UserInfo UI = new UserInfo(strValue[0], strValue[1], strCon);

                int iPos = strValue[2].LastIndexOf("\\");

                if (iPos > 0)
                    strValue[2] = strValue[2].Substring(iPos);

                if (!Directory.Exists(UI.UserPath + "\\attach_temp"))
                    Directory.CreateDirectory(UI.UserPath + "\\attach_temp");

                strPath = UI.UserPath + "\\attach_temp\\" + strValue[2];// + "?" + lUploadSize.ToString();

                if (File.Exists(strPath))
                {
                 
                    //2010.03.15 파일 사이즈 가져 오는 부분 수정함.
                    //strPath += "?" + lUploadSize.ToString();

                    FileInfo fi = new FileInfo(strPath);
                    //lFileSize = fi.Length;

                    strPath += "?" + fi.Length.ToString();

                }
                else
                    strPath += "?-1";
            } else
            {
                // 웹하드 일때 사용자 경로를 가져온다.
                if (strValue.Length < 5)
                    SoapCustomException("", "Not enough argument");

                if (strValue.Length > 5)
                    SoapCustomException("", "Too many argument");

                fu.ConnectionString = strCon;
                fu.Domain = strValue[0];
                fu.MemberId = strValue[1];
                fu.GroupName = strValue[2];
                fu.FolderName = strValue[3];
                fu.FileName = strValue[4];
                
                // 그룹과 사용자 아이디 체크
                if (!fu.CheckGroupMember(lUploadSize))
                    SoapCustomException("", "업로드 경로 사용자 아이디 에러: " +fu.ErrorMessage);

                strPath = fu.GetUploadPath();
            }

            if (strPath.Trim() == "")
                SoapCustomException("", "업로드 경로 에러(경로 없음): " + fu.ErrorMessage);
        }
        catch (Exception e)
        {
            SoapCustomException("", "업로드 경로 에러: " + e.Message);
        }
        
        return Convert.ToBase64String(Encoding.UTF8.GetBytes(strPath));
    }

    //09.10.13 파일 업로드 할때 2기가 이상 업로드 할때 애러 발생 iOffSet가 int형으로 되어 있는데 long형으로 변경함.
    [WebMethod(EnableSession=true)]
    public void AppendFileData(string strPath, byte[] buf, long iOffSet, int iReadByte)
    {
        try
        {
            strPath = Encoding.UTF8.GetString(Convert.FromBase64String(strPath));

            fu.AppendFileData(strPath, buf, iOffSet, iReadByte);
        }
        catch (Exception e)
        {
            SoapCustomException("", "서버에 파일 저장 에러: " + e.Message);
        }
    }

    [WebMethod(EnableSession = true)]
    public string GetFilePath(string strArgs)
    {
        bool result = false;
        string[] strValue; ;
        string strPath = "";

        try
        {
            string strDomain = "";
            string strMemberId = "";
            string strGroupName = "";
            string strFilePath = "";
            string strFilename = "";

            strValue = Encoding.UTF8.GetString(Convert.FromBase64String(strArgs)).Split(':');

            if (strValue.Length < 5)
                SoapCustomException("", "Not enough argument");

            if (strValue.Length > 5)
                SoapCustomException("", "Too many argument");

            strDomain = strValue[0];
            strMemberId = strValue[1];
            strGroupName = strValue[2];
            strFilePath = strValue[3].Replace("|", "\\");
            strFilename = strValue[4];

            fd.ConnectionString = strCon;
            result = fd.CheckDownloadPermission(strDomain, strMemberId, strGroupName);

            if (!result)
                throw new Exception(fd.ErrorMessage);

            if (strGroupName.Trim() != "")
                strPath = fd.GetPath(strDomain, strGroupName, true);
            else
                strPath = fd.GetPath(strDomain, strMemberId, false);

            if (!strFilePath.StartsWith("\\"))
                strFilePath = "\\" + strFilePath;

            if (!strFilePath.EndsWith("\\"))
                strFilePath += "\\";

            strPath += strFilePath + strFilename;;
        }
        catch (Exception e)
        {
            throw new Exception("경로 가져오기 에러: " + e.Message);
        }

        return Convert.ToBase64String(Encoding.UTF8.GetBytes(strPath));
    }

    [WebMethod(EnableSession = true)]
    public byte[] DownloadFileData(string strPath, long lOffSet, int iBufSize)
    {
        byte[] tmp = null;

        try
        {
            strPath = Encoding.UTF8.GetString(Convert.FromBase64String(strPath));

            tmp = fd.DownloadFile(strPath, lOffSet, iBufSize);
        }
        catch (Exception e)
        {
            SoapCustomException("", "파일 다운로드 에러: " + e.Message);
        }

        return tmp;
    }

    [WebMethod(EnableSession = true)]
    public double ResultSize(string strPath)
    {
        double dSize = 0;

        try
        {
            if (strPath.Trim() == "")
                SoapCustomException("", "not exists upload path");

            strPath = Encoding.UTF8.GetString(Convert.FromBase64String(strPath));

            if (File.Exists(strPath))
            {
                FileInfo fi = new FileInfo(strPath);

                dSize = fi.Length;
            }
            else
                SoapCustomException("", "not exists upload file");
        }
        catch (Exception e)
        {
            SoapCustomException("", "파일 용량 에러: " + e.Message);
        }

        return dSize;
    }

    [WebMethod(EnableSession = true)]
    public void DeleteFile(string strPath)
    {
        try
        {
            if (strPath.Trim() == "")
                SoapCustomException("", "not exists upload path");

            strPath = Encoding.UTF8.GetString(Convert.FromBase64String(strPath));

            if (File.Exists(strPath))
                File.Delete(strPath);
        }
        catch (Exception e)
        {
            SoapCustomException("", "파일 삭제 에러: " + e.Message);
        }
    }

    public static void SoapCustomException(string strExceptionName, string strExceptionMessage)
    {
        System.Web.Services.Protocols.SoapException se = new SoapException(strExceptionMessage, SoapException.ClientFaultCode);
        
        throw se;

        //throw new System.Web.Services.Protocols.SoapException(strExceptionName + " : " + strExceptionMessage, new System.Xml.XmlQualifiedName("Passkorea Uploader"));
    }

    [WebMethod]
    public string ErrorMessage()
    {
        return __strErr;
    }
}