﻿using System;
using System.Data;
using System.Data.OleDb;
using System.Configuration;
using System.Collections;
using System.IO;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;
using Passkorea;

public partial class Config_MailBox_BackupMailbox : System.Web.UI.Page
{
    private OleDbConnection Con;
    private OleDbTransaction Trans;
    private OleDbCommand Cmd = new OleDbCommand();
    private OleDbParameter Param = new OleDbParameter();
    private UserInfo UI;
    private JavaScript JS;

    private int MAX_MAIL_COUNT = 1000;
    private string strCon = ConfigurationSettings.AppSettings["strConnection"];
    private string strDomain = "";
    private string strUserId = "";
    private string strMailBox = "";
    protected int iMailCount = 0;
    protected string strMailboxName = "";
    protected string strMailboxSize = "";

    protected void Page_Load(object sender, EventArgs e)
    {
        JS = new JavaScript(this.Page);
        JS.LoginCheck(Session["USER_ID"], "../../log/login.aspx", true);

        strDomain = Session["MAIL_DOMAIN"].ToString();
        strUserId = Session["USER_ID"].ToString();
        strMailBox = Request.Params["strMailBox"].ToLower();
        UI = new UserInfo(strUserId, strDomain, strCon);

        if (!Page.IsPostBack)
        {
            this.GetMailboxInfo();
        }
    }

    #region 편지함 정보가져오기
    /// <summary>
    /// 편지함 정보가져오기
    /// </summary>
    private void GetMailboxInfo()
    {
        DataTable dt = new DataTable();
        long iMailboxSize = 0;
        int iCount = 0;
        int iMod = 0;

        try
        {
            if (Con == null)
                Con = new OleDbConnection(strCon);

            Con.Open();
        }
        catch (Exception e)
        {
            JS.MessageBox(e.Message);
            return;
        }

        try
        {
            Cmd.Connection = Con;
            Cmd.CommandType = CommandType.StoredProcedure;
            Cmd.CommandText = "prLoadMailbox";

            Cmd.Parameters.Clear();

            Param = Cmd.Parameters.Add("@iResult", OleDbType.Integer);
            Param.Direction = ParameterDirection.ReturnValue;

            Param = Cmd.Parameters.Add("@strUserId", OleDbType.VarChar, strUserId.Length);
            Param.Direction = ParameterDirection.Input;

            Param = Cmd.Parameters.Add("@strDomain", OleDbType.VarChar, strDomain.Length);
            Param.Direction = ParameterDirection.Input;

            Param = Cmd.Parameters.Add("@iMailboxIdx", OleDbType.SmallInt);
            Param.Direction = ParameterDirection.Input;

            Cmd.Parameters["@strUserId"].Value = strUserId;
            Cmd.Parameters["@strDomain"].Value = strDomain;
            Cmd.Parameters["@iMailboxIdx"].Value = int.Parse(strMailBox);

            OleDbDataReader reader = Cmd.ExecuteReader();

            if (reader.HasRows)
            {
                WebFunction WF = new WebFunction();
                reader.Read();

                strMailboxName = reader["M_Mailbox_Name"].ToString();
                iMailCount = int.Parse(reader["M_Mail_Count"].ToString());
                iMailboxSize = long.Parse(reader["M_Use_Size"].ToString());
                strMailboxSize = WF.GetFileSize(iMailboxSize);
            }

            reader.Close();

            dt.Clear();

            iCount = iMailCount / MAX_MAIL_COUNT;
            iMod = iMailCount % MAX_MAIL_COUNT;

            if (iMod > 0)
                iCount++;

            dt.Columns.Add("Mailbox_Idx", Type.GetType("System.String"));
            dt.Columns.Add("Mail_Count", Type.GetType("System.String"));
            dt.Columns.Add("Show_Count", Type.GetType("System.String"));

            for (int i = 1; i <= iCount; i++)
            {
                DataRow dr = dt.NewRow();
                int iStart = 0;
                int iEnd = 0;

                iStart = ((i - 1) * MAX_MAIL_COUNT) + 1;
                iEnd = i * MAX_MAIL_COUNT;

                if (iEnd > iMailCount)
                    iEnd = iMailCount;

                dr["Mailbox_Idx"] = strMailBox;
                dr["Mail_Count"] = i;
                dr["Show_Count"] = iStart.ToString() + " ~ " + iEnd.ToString() + " 개 메일 백업 ";

                dt.Rows.Add(dr);
            }

            rptBackupMailbox.DataSource = dt;
            rptBackupMailbox.DataBind();
        }
        catch (Exception e)
        {
            Con.Close();
            JS.MessageBox(e.Message);
            JS.HistoryBack();
            return;
        }
        finally
        {
            if (Con.State != ConnectionState.Closed)
                Con.Close();
        }
    }
    #endregion

    #region 편지함 백업
    /// <summary>
    /// 편지함 백업
    /// </summary>
    /// <param name="sender"></param>
    /// <param name="e"></param>
    protected void ibBackup_Command(object sender, CommandEventArgs e)
    {
        DataSet ds = new DataSet();
        DataTable dt = new DataTable();
        string strMailCount = e.CommandArgument.ToString();
        string strCompressFile = "";

        try
        {
            if (Con == null)
                Con = new OleDbConnection(strCon);

            Con.Open();
        }
        catch (Exception err)
        {
            JS.MessageBox(err.Message);
            JS.HistoryBack();
            return;
        }

        try
        {
            int iMailCount = int.Parse(strMailCount);

            strCompressFile = strUserId + "_" + DateTime.Now.ToString("yyyyMMdd") + "_" + strMailBox + "_" + iMailCount + ".zip";

            Cmd.Connection = Con;
            Cmd.CommandType = CommandType.StoredProcedure;
            Cmd.CommandText = "prListMail";

            Cmd.Parameters.Clear();

            Param = Cmd.Parameters.Add("@iResult", OleDbType.Integer);
            Param.Direction = ParameterDirection.ReturnValue;

            Param = Cmd.Parameters.Add("@strUserId", OleDbType.VarChar, strUserId.Length);
            Param.Direction = ParameterDirection.Input;

            Param = Cmd.Parameters.Add("@strDomain", OleDbType.VarChar, strDomain.Length);
            Param.Direction = ParameterDirection.Input;

            Param = Cmd.Parameters.Add("@iMailboxIdx", OleDbType.SmallInt);
            Param.Direction = ParameterDirection.Input;

            Param = Cmd.Parameters.Add("@strSearchType", OleDbType.VarChar, 0);
            Param.Direction = ParameterDirection.Input;

            Param = Cmd.Parameters.Add("@strSearchValue", OleDbType.VarWChar, 0);
            Param.Direction = ParameterDirection.Input;

            Param = Cmd.Parameters.Add("@strStartDate", OleDbType.VarChar, 0);
            Param.Direction = ParameterDirection.Input;

            Param = Cmd.Parameters.Add("@strEndDate", OleDbType.VarChar, 0);
            Param.Direction = ParameterDirection.Input;

            Param = Cmd.Parameters.Add("@iPage", OleDbType.Integer);
            Param.Direction = ParameterDirection.Input;

            Param = Cmd.Parameters.Add("@iPageSize", OleDbType.Integer);
            Param.Direction = ParameterDirection.Input;

            //2010.03.09 추가
            Param = Cmd.Parameters.Add("@strIs_Read", OleDbType.VarChar, 4);
            Param.Direction = ParameterDirection.Input;

            Param = Cmd.Parameters.Add("@iTotalCount", OleDbType.Integer);
            Param.Direction = ParameterDirection.Output;

            Param = Cmd.Parameters.Add("@iNoReadCount", OleDbType.Integer);
            Param.Direction = ParameterDirection.Output;

            Cmd.Parameters["@strUserId"].Value = strUserId;
            Cmd.Parameters["@strDomain"].Value = strDomain;
            Cmd.Parameters["@iMailboxIdx"].Value = int.Parse(strMailBox);
            Cmd.Parameters["@strSearchType"].Value = "";
            Cmd.Parameters["@strSearchValue"].Value = "";
            Cmd.Parameters["@strStartDate"].Value = "";
            Cmd.Parameters["@strEndDate"].Value = "";
            Cmd.Parameters["@iPage"].Value = iMailCount;
            Cmd.Parameters["@iPageSize"].Value = 1000;
            //2010.03.09 추가
            Cmd.Parameters["@strIs_Read"].Value = "";

            OleDbDataAdapter Adap = new OleDbDataAdapter(Cmd);
            Adap.Fill(ds, "MAIL_LIST");
            dt = ds.Tables["MAIL_LIST"];

            if (dt != null)
            {
                Server.ScriptTimeout = 600;
                java.io.FileOutputStream fos = new java.io.FileOutputStream(UI.UserPath + "\\temp\\" + strCompressFile);
                java.util.zip.ZipOutputStream zos = new java.util.zip.ZipOutputStream(fos);

                foreach (DataRow dr in dt.Rows)
                {
                    string filePath = UI.UserPath + "\\" + dr["Mc_Mailbox_No"].ToString();
                    string filename = dr["Mc_Filename"].ToString();

                    if (File.Exists(filePath + "\\" + filename))
                    {
                        java.io.FileInputStream fis = new java.io.FileInputStream(filePath + "\\" + filename);
                        java.util.zip.ZipEntry ze = new java.util.zip.ZipEntry(filename);
                        zos.putNextEntry(ze);

                        sbyte[] buf = new sbyte[1024];
                        int len = 0;

                        while ((len = fis.read(buf)) >= 0)
                            zos.write(buf, 0, len);

                        zos.closeEntry();
                        fis.close();
                    }
                }

                zos.close();
                fos.close();

                FileInfo f = new FileInfo(UI.UserPath + "\\temp\\" + strCompressFile);

                if (f.Exists)
                {
                    Response.Clear();
                    Response.ClearContent();
                    Response.ContentType = "Application/Octet-stream";
                    Response.AddHeader("Content-Disposition", "attachment; filename=" + f.Name);

                    //09.11.18 다운로드 형식 변경함.
                    Response.TransmitFile(UI.UserPath + "\\temp\\" + strCompressFile);
                    Response.Flush();
                    Response.End();
                    return;
                }
            }
            else
            {
                JS.MessageBox("백업할 편지가 없습니다.");
                JS.WindowsClose();
            }
        }
        catch (Exception err)
        {
            Con.Close();
            JS.MessageBox(err.Message);
            JS.WindowsClose();
            return;
        }
        finally
        {
            if (Con.State != ConnectionState.Closed)
                Con.Close();
        }
    }
    #endregion
}
